==> gtreg_0.1.1.tar.gz: gtreg/R/reexport.R <==
# dplyr ------------------------------------------------------------------------
#' @export
#' @importFrom dplyr %>%
dplyr::`%>%`

#' @importFrom dplyr vars
#' @export
dplyr::vars

#' @importFrom dplyr select
#' @export
dplyr::select

#' @importFrom dplyr starts_with
#' @export
dplyr::starts_with

#' @importFrom dplyr ends_with
#' @export
dplyr::ends_with

#' @importFrom dplyr contains
#' @export
dplyr::contains

#' @importFrom dplyr matches
#' @export
dplyr::matches

#' @importFrom dplyr num_range
#' @export
dplyr::num_range

#' @importFrom dplyr all_of
#' @export
dplyr::all_of

#' @importFrom dplyr any_of
#' @export
dplyr::any_of

#' @importFrom dplyr everything
#' @export
dplyr::everything

#' @importFrom dplyr last_col
#' @export
dplyr::last_col

#' @importFrom dplyr one_of
#' @export
dplyr::one_of

# knitr ------------------------------------------------------------------------
#' @export
#' @importFrom knitr knit_print
knitr::knit_print

# tibble -----------------------------------------------------------------------
#' @export
#' @importFrom tibble as_tibble
tibble::as_tibble

# gtsummary --------------------------------------------------------------------
#' @importFrom gtsummary as_gt
#' @export
gtsummary::as_gt

#' @importFrom gtsummary as_flex_table
#' @export
gtsummary::as_flex_table

#' @importFrom gtsummary as_hux_table
#' @export
gtsummary::as_hux_table

#' @importFrom gtsummary as_kable
#' @export
gtsummary::as_kable

#' @importFrom gtsummary as_kable_extra
#' @export
gtsummary::as_kable_extra

#' @importFrom gtsummary inline_text
#' @export
gtsummary::inline_text

#' @importFrom gtsummary add_overall
#' @export
gtsummary::add_overall

#' @importFrom gtsummary modify_spanning_header
#' @export
gtsummary::modify_spanning_header

#' @importFrom gtsummary modify_header
#' @export
gtsummary::modify_header

#' @importFrom gtsummary modify_footnote
#' @export
gtsummary::modify_footnote

#' @importFrom gtsummary modify_caption
#' @export
gtsummary::modify_caption

#' @importFrom gtsummary modify_column_indent
#' @export
gtsummary::modify_column_indent

#' @importFrom gtsummary bold_labels
#' @export
gtsummary::bold_labels

#' @importFrom gtsummary bold_levels
#' @export
gtsummary::bold_levels

#' @importFrom gtsummary italicize_labels
#' @export
gtsummary::italicize_labels

#' @importFrom gtsummary italicize_labels
#' @export
gtsummary::italicize_labels

#' @importFrom gtsummary bold_labels
#' @export
gtsummary::bold_labels

#' @importFrom gtsummary show_header_names
#' @export
gtsummary::show_header_names

#' @importFrom gtsummary style_number
#' @export
gtsummary::style_number

#' @importFrom gtsummary style_sigfig
#' @export
gtsummary::style_sigfig

#' @importFrom gtsummary style_percent
#' @export
gtsummary::style_percent

==> gtreg_0.4.1.tar.gz: gtreg/R/reexport.R <==
# dplyr ------------------------------------------------------------------------
#' @export
#' @importFrom dplyr %>%
dplyr::`%>%`

#' @importFrom dplyr vars
#' @export
dplyr::vars

#' @importFrom dplyr select
#' @export
dplyr::select

#' @importFrom dplyr where
#' @export
dplyr::where

#' @importFrom dplyr starts_with
#' @export
dplyr::starts_with

#' @importFrom dplyr ends_with
#' @export
dplyr::ends_with

#' @importFrom dplyr contains
#' @export
dplyr::contains

#' @importFrom dplyr matches
#' @export
dplyr::matches

#' @importFrom dplyr num_range
#' @export
dplyr::num_range

#' @importFrom dplyr all_of
#' @export
dplyr::all_of

#' @importFrom dplyr any_of
#' @export
dplyr::any_of

#' @importFrom dplyr everything
#' @export
dplyr::everything

#' @importFrom dplyr last_col
#' @export
dplyr::last_col

#' @importFrom dplyr one_of
#' @export
dplyr::one_of

# tibble -----------------------------------------------------------------------
#' @export
#' @importFrom tibble as_tibble
tibble::as_tibble

# gtsummary --------------------------------------------------------------------
#' @importFrom gtsummary as_gt
#' @export
gtsummary::as_gt

#' @importFrom gtsummary as_flex_table
#' @export
gtsummary::as_flex_table

#' @importFrom gtsummary as_hux_table
#' @export
gtsummary::as_hux_table

#' @importFrom gtsummary as_hux_xlsx
#' @export
gtsummary::as_hux_xlsx

#' @importFrom gtsummary as_kable
#' @export
gtsummary::as_kable

#' @importFrom gtsummary as_kable_extra
#' @export
gtsummary::as_kable_extra

#' @importFrom gtsummary inline_text
#' @export
gtsummary::inline_text

#' @importFrom gtsummary add_overall
#' @export
gtsummary::add_overall

#' @importFrom gtsummary modify_spanning_header
#' @export
gtsummary::modify_spanning_header

#' @importFrom gtsummary modify_header
#' @export
gtsummary::modify_header

#' @importFrom gtsummary modify_footnote
#' @export
gtsummary::modify_footnote

#' @importFrom gtsummary modify_caption
#' @export
gtsummary::modify_caption

#' @importFrom gtsummary modify_column_indent
#' @export
gtsummary::modify_column_indent

#' @importFrom gtsummary bold_labels
#' @export
gtsummary::bold_labels

#' @importFrom gtsummary bold_levels
#' @export
gtsummary::bold_levels

#' @importFrom gtsummary italicize_labels
#' @export
gtsummary::italicize_labels

#' @importFrom gtsummary italicize_labels
#' @export
gtsummary::italicize_labels

#' @importFrom gtsummary bold_labels
#' @export
gtsummary::bold_labels

#' @importFrom gtsummary show_header_names
#' @export
gtsummary::show_header_names

#' @importFrom gtsummary style_number
#' @export
gtsummary::style_number

#' @importFrom gtsummary style_sigfig
#' @export
gtsummary::style_sigfig

#' @importFrom gtsummary style_percent
#' @export
gtsummary::style_percent

#' @importFrom gtsummary all_continuous
#' @export
gtsummary::all_continuous

#' @importFrom gtsummary all_continuous2
#' @export
gtsummary::all_continuous2

#' @importFrom gtsummary all_categorical
#' @export
gtsummary::all_categorical

#' @importFrom gtsummary all_stat_cols
#' @export
gtsummary::all_stat_cols
